Table of contents
-----------------

* Introduction
* Features
* Installation
* Sub-modules
* Contributed modules
* FAQ
* Notes
* Known Issues


Introduction
------------

The **Schema.org Blueprint Demo module** provides an opinionated demo of the
Schema.org Blueprints built on top of Drupal's standard profile with default
content and translations.

This module provides a composer.libraries.json file that allows sites to
download and install contributed modules with patches which are used to set up
a full demo of the Schema.org Blueprints module within a progressively decoupled
Drupal instance.

**THIS MODULE SHOULD ONLY BE INSTALLED ON A PLAIN VANILLA STANDARD
INSTANCE OF DRUPAL**


Features
--------

**Administration**

A radically new administration interface using the Gin admin theme

- Modern administrative theme
- Dedicated and branded login page
- Customizable administrative toolbar
- Customizable administrative dashboards

**Content authoring**

Examples of Drupal's content authoring best practices and patterns

- Media support
- Media library
- Paragraph library
- Embedded content
- Content browsing
- Inline entity forms
- Automatic entity labels
- Content cloning
- Drag-n-drop file uploads
- Link management
- PDF generation
- URL generation
- Decoupling using Next.js

**Multilingual support**

- Language switching

**Default content**

- Example recipes in English and Spanish copied from the
  [Umami demo install profile](https://www.drupal.org/docs/umami-drupal-demonstration-installation-profile).


Installation
------------

- [Use Composer to Install Drupal and Manage Dependencies](https://www.drupal.org/docs/develop/using-composer/manage-dependencies)
- [Install the Schema.org Blueprints view composer](https://www.drupal.org/project/schemadotorg/releases/1.0.x-dev)
  - Run `composer require '- **[](https://www.drupal.org/project/schemadotorg_demo:1.0.x-dev@dev'`
- [Install the Composer Merge Plugin](https://github.com/wikimedia/composer-merge-plugin)
  - Run `composer require wikimedia/composer-merge-plugin`
- Add the Schema.org Blueprints Demo's composer.libraries.json to composer.json
  - Update the root `composer.json` file to include `schemadotorg/composer.libraries.json` and `schemadotorg_demo/composer.libraries.json`
  - See the below example of the composer.libraries.json added to composer.json
- Install the Schema.org Blueprints Demo
  - **OPTION 1**
    - Install plain vanilla standard instance of Drupal
      - Run `drush site-install`
    - Install the Schema.org Blueprints Demo
      - Run `drush en schemadotorg_demo`
  - **OPTION 2**
    - Install [Schema.org Blueprint Demo profile](https://www.drupal.org/sandbox/jrockowitz/3355842).
      - Run `drush site-install schemadotorg_demo_profile`
    - Install the Schema.org Blueprints Demo
      - Run `drush en schemadotorg_demo`
  - **OPTIONS 3**
    - From the root run one of the below scripts which required the [Schema.org Blueprint Demo profile](https://www.drupal.org/sandbox/jrockowitz/3355842).
      - `web/modules/contrib/schemadotorg_demo/scripts/schemadotorg_demo.sh install_demo_standard`
      - `web/modules/contrib/schemadotorg_demo/scripts/schemadotorg_demo.sh install_demo_standard_next`
      - `web/modules/contrib/schemadotorg_demo/scripts/schemadotorg_demo.sh install_demo_standard_translation`
      - `web/modules/contrib/schemadotorg_demo/scripts/schemadotorg_demo.sh install_demo_standard_translation_umami`


Below is an example of what must be added to your projects composer.json file to include Schema.org Blueprints Demo.

```
{
    "require": {
        "- **[](https://www.drupal.org/project/schemadotorg": "1.0.x-dev@dev",
        "- **[](https://www.drupal.org/project/schemadotorg_demo": "1.0.x-dev@dev",
        "wikimedia/composer-merge-plugin": "^2.0"
    },
    "config": {
        "allow-plugins": {
            "wikimedia/composer-merge-plugin": true
        },
    },
    "extra": {
        "merge-plugin": {
            "include": [
                "web/modules/contrib/dropzonejs/composer.libraries.json",
                "web/modules/contrib/schemadotorg/composer.libraries.json",
                "web/modules/contrib/schemadotorg_demo/composer.libraries.json"
            ],
            "merge-extra": true,
            "merge-extra-deep": true
        }
    }
}
```


Sub-modules
-----------

Below are sub-modules when install enable different functionality and featuresets.

- **[Schema.org Blueprints Demo Standard Profile Setup](https://git.drupalcode.org/project/schemadotorg_demo/-/tree/1.0.x/modules/schemadotorg_demo_standard)**  
  Provides an opinionated demo of the Schema.org Blueprints built on top of Drupal's standard profile.

- **[Schema.org Blueprints Demo Standard Profile Translation](https://git.drupalcode.org/project/schemadotorg_demo/-/tree/1.0.x/modules/schemadotorg_demo_standardard_translation)**  
  Provides an opinionated translation of the Schema.org Blueprints built on top of Drupal's standard profile.

- **[Schema.org Blueprints Demo Standard Profile Admin](https://git.drupalcode.org/project/schemadotorg_demo/-/tree/1.0.x/modules/schemadotorg_demo_standard_admin)**  
  Provides admin UI enhancements for the Schema.org Blueprints demo built on top of Drupal's standard profile.

- **[Schema.org Blueprints Default Content](https://git.drupalcode.org/project/schemadotorg_demo/-/tree/1.0.x/modules/schemadotorg_demo_default_content)**  
  Provides default Schema.org types and mappings with default content.

- **[Schema.org Blueprints Umami Demo Content](https://git.drupalcode.org/project/schemadotorg_demo/-/tree/1.0.x/modules/schemadotorg_demo_umami_content)**  
  Imports the content for the Umami demo with Schema.org Blueprints.

- **[Schema.org Blueprints Demo Next.js](https://git.drupalcode.org/project/schemadotorg_demo/-/tree/1.0.x/modules/schemadotorg_demo_next)**  
  Provides a demo Schema.org Blueprints used Next.js for Drupal.


Contributed modules
-------------------

Below are contributed module included in the demo to enhance the user and content authoring experience.

- **[Admin Toolbar](https://www.drupal.org/project/admin_toolbar)**  
  Provides a drop-down menu interface to the core Drupal Toolbar.

- **[Autosave Form](https://www.drupal.org/project/autosave_form)**  
  Adds autosave feature on forms.

- **[Chosen](https://www.drupal.org/project/chosen)**  
  Makes select elements more friendly using the Chosen jQuery plugin

- **[CKEditor Paste Filter](https://www.drupal.org/project/ckeditor_paste_filter)**  
  Extra plugins for ckeditor. Filter text pasted into editor.

- **[Dashboards](https://www.drupal.org/project/dashboards)**  
  Dashboards based on Layout Builder.

- **[Defaul Content](https://www.drupal.org/project/default_content)**  
  Imports default content when a module is enabled

- **[Diff](https://www.drupal.org/project/diff)**  
  Compares two entity revisions

- **[DropzonJS](https://www.drupal.org/project/dropzonejs)**  
  Drupal integration for DropzoneJS - An open source library that provides drag’n’drop file uploads.

- **[Entity Clone](https://www.drupal.org/project/entity_clone)**  
  Add a clone action for all entities.

- **[Entity Print](https://www.drupal.org/project/entity_print)**  
  PDF print solution for any Drupal entity.

- **[Environment Indicator](https://www.drupal.org/project/environment_indicator)**  
  Adds a color indicator for the different environments.

- **[Gin](https://www.drupal.org/project/gin)**  
  For a better Admin and Content Editor Experience.

- **[Gin Layout Builder](https://www.drupal.org/project/gin_lb)**  
  Gin Layout Builder

- **[Gin Login](https://www.drupal.org/project/gin_login)**  
  Custom Drupal Login for Gin theme

- **[Gin Toolbar](https://www.drupal.org/project/gin_toolbar)**  
  Gin Toolbar for Frontend use

- **[Linkit](https://www.drupal.org/project/linkit)**  
  Provides an autocomplete interface for internal and external linking in rich-text editors.

- **[Media Bulk Upload](https://www.drupal.org/project/media_bulk_upload)**  
  Allows uploading files in bulk and converting them to media entities.

- **[Moderation Dashboard](https://www.drupal.org/project/moderation_dashboard)**  
  Provides a per-user dashboard that contains useful blocks related to managing moderated content.

- **[Moderation Sidebar](https://www.drupal.org/project/moderation_sidebar)**  
  Provides a frontend sidebar for Content Moderation

- **[Multiple Fields Remove Button](https://www.drupal.org/project/multiple_fields_remove_button)**  
  Add remove button for multi showing fields.

- **[Node Edit Protection](https://www.drupal.org/project/node_edit_protection)**  
  Protect the user against navigating away from a node edit form before saving their changes.

- **[Admin Toolbar Language Switcher](https://www.drupal.org/project/toolbar_language_switcher)**  
  Adds the Toolbar Language Switcher to the administration toolbar of the project.

  
FAQ
---

**Why does this module only contain a composer.libraries.json file and \*.info.yml file?**

The composer.libraries.json file provides a quick way to include or cut-n-paste
the demo's dependencies. The \*.info.yml file provides a single module that is
used to enable the installation of a complete demo while allowing individual
parts of the demo to be maintained as smaller modules.


Notes
-----

The **Schema.org Blueprints Demo module** and sub-modules may be moved to a
dedicated project on Drupal.org.

The below patch breaks the Next.js module's JSON:API support.

    "patches": {
      "- **[](https://www.drupal.org/project/core": {
        "Issue #3100732: Allow specifying `meta` data on JSON:API objects": "https://www.drupal.org/files/issues/2022-05-15/3100732-33.patch"
      },
    }


Known Issues
------------

- [Issue #3316265: Field description is not displayed for text format (i.e. body)](https://www.drupal.org/project/gin/issues/3316265 )
