<?php

declare(strict_types = 1);

namespace Drupal\schemadotorg_demo_standard\Plugin\Block;

use Drupal\Core\Access\AccessResult;
use Drupal\Core\Block\BlockBase;
use Drupal\Core\Plugin\ContainerFactoryPluginInterface;
use Drupal\Core\Session\AccountInterface;
use Symfony\Component\DependencyInjection\ContainerInterface;

/**
 * Provides a 'Schema.org Blueprints' shortcuts block.
 *
 * @Block(
 *   id = "schemadotorg_demo_standard",
 *   admin_label = @Translation("Schema.org Blueprints"),
 *   category = @Translation("Menus")
 * )
 */
class SchemaDotOrgDemoStandardBlock extends BlockBase implements ContainerFactoryPluginInterface {

  /**
   * The entity type manager.
   *
   * @var \Drupal\core\Entity\EntityTypeManagerInterface
   */
  protected $entityTypeManager;

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container, array $configuration, $plugin_id, $plugin_definition) {
    $instance = new static($configuration, $plugin_id, $plugin_definition);
    $instance->entityTypeManager = $container->get('entity_type.manager');
    return $instance;
  }

  /**
   * {@inheritdoc}
   */
  public function build() {
    /** @var \Drupal\shortcut\ShortcutSetInterface $shortcut_set */
    $shortcut_set = $this->entityTypeManager
      ->getStorage('shortcut_set')
      ->load('schemadotorg');
    $build = shortcut_renderable_links($shortcut_set);
    $build['#theme'] = 'dashboards_admin_list';
    $build['#list'] = $build['#links'];
    return $build;
  }

  /**
   * {@inheritdoc}
   */
  protected function blockAccess(AccountInterface $account) {
    return AccessResult::allowedIfHasPermission($account, 'access shortcuts');
  }

}
